@@ -188,6 +188,15 @@ MainWindow::MainWindow(QWidget *parent)
     SLOT(clearSelection()),
     Qt::QueuedConnection);
 
+  // For panels performing tricky operations, need to know when the context
+  // changes:
+  connect(
+    ui->mainTabWidget,
+    SIGNAL(currentChanged(int)),
+    this,
+    SLOT(reportContextChange(int)),
+    Qt::QueuedConnection);
+
 #ifndef DEBUGGING
   // The PIRModprobe object should take care of setting up and shutting down
   // the lirc_rx51 kernel module, if necessary:
@@ -505,6 +514,13 @@ void MainWindow::keysetSelectionChanged(
 }
 
 
+void MainWindow::reportContextChange(
+  int tabnum)
+{
+  emit contextChanged();
+}
+
+
 void MainWindow::finalCleanup()
 {
   // Perform any necessary cleanup work here.
